@@ -130,37 +130,24 @@ def _build_url(
 
 
 def _current_weather_all(current_weather: CurrentWeather, units: str, am_pm: bool) -> Table:
-    temp_unit = _temp_units(units)
-    speed_unit = _speed_units(units)
-    precip_unit = _precip_units(units)
+    precip_unit, _, speed_units, temp_units = _get_units(units)
     conditions = current_weather.weather[0].description
     weather_icon = WeatherIcons.get_icon(conditions)
     if weather_icon:
         conditions += f" {weather_icon}"
-    if not am_pm:
-        sunrise = str(
-            (current_weather.sys.sunrise + timedelta(seconds=current_weather.timezone)).time()
-        )
-        sunset = str(
-            (current_weather.sys.sunset + timedelta(seconds=current_weather.timezone)).time()
-        )
-    else:
-        sunrise = datetime.strftime(
-            (current_weather.sys.sunrise + timedelta(seconds=current_weather.timezone)), "%I:%M %p"
-        )
-        sunset = datetime.strftime(
-            (current_weather.sys.sunset + timedelta(seconds=current_weather.timezone)), "%I:%M %p"
-        )
+    sunrise, sunset = _format_sunrise_sunset(
+        am_pm, current_weather.sys.sunrise, current_weather.sys.sunset, current_weather.timezone
+    )
 
     table = Table(
         title=f"Current weather for {current_weather.name}", header_style=HEADER_ROW_STYLE
     )
-    table.add_column(f"Temperature ({temp_unit}) :thermometer:")
-    table.add_column(f"Feels Like ({temp_unit}) :thermometer:")
+    table.add_column(f"Temperature ({temp_units}) :thermometer:")
+    table.add_column(f"Feels Like ({temp_units}) :thermometer:")
     table.add_column("Humidity")
     table.add_column("Conditions")
-    table.add_column(f"Wind Speed ({speed_unit})")
-    table.add_column(f"Wind Gusts ({speed_unit})")
+    table.add_column(f"Wind Speed ({speed_units})")
+    table.add_column(f"Wind Gusts ({speed_units})")
     table.add_column(f"Rain 1 Hour ({precip_unit}) :cloud_with_rain:")
     table.add_column(f"Rain 3 Hour ({precip_unit}) :cloud_with_rain:")
     table.add_column(f"Snow 1 Hour ({precip_unit}) :snowflake:")
@@ -168,53 +155,34 @@ def _current_weather_all(current_weather: CurrentWeather, units: str, am_pm: boo
     table.add_column("Sunrise :sunrise:")
     table.add_column("Sunset :sunset:")
 
-    if current_weather.rain and current_weather.rain.one_hour:
-        rain_one_hour = (
-            str(_mm_to_in(current_weather.rain.one_hour))
-            if units == "imperial"
-            else str(current_weather.rain.one_hour)
-        )
+    if current_weather.rain:
+        rain_one_hour = _format_precip(current_weather.rain.one_hour, units)
+        rain_three_hour = _format_precip(current_weather.rain.three_hour, units)
     else:
         rain_one_hour = "0"
-
-    if current_weather.rain and current_weather.rain.three_hour:
-        rain_three_hour = (
-            str(_mm_to_in(current_weather.rain.three_hour))
-            if units == "imperial"
-            else str(current_weather.rain.three_hour)
-        )
-    else:
         rain_three_hour = "0"
 
-    if current_weather.snow and current_weather.snow.one_hour:
-        snow_one_hour = (
-            str(_mm_to_in(current_weather.snow.one_hour))
-            if units == "imperial"
-            else str(current_weather.snow.one_hour)
-        )
+    if current_weather.snow:
+        snow_one_hour = _format_precip(current_weather.snow.one_hour, units)
+        snow_three_hour = _format_precip(current_weather.snow.three_hour, units)
     else:
         snow_one_hour = "0"
-
-    if current_weather.snow and current_weather.snow.three_hour:
-        snow_three_hour = (
-            str(_mm_to_in(current_weather.snow.three_hour))
-            if units == "imperial"
-            else str(current_weather.snow.three_hour)
-        )
-    else:
         snow_three_hour = "0"
 
+    if current_weather.wind:
+        wind = _format_wind(current_weather.wind.speed, units)
+        gusts = _format_wind(current_weather.wind.gust, units)
+    else:
+        wind = "0"
+        gusts = "0"
+
     table.add_row(
         str(round(current_weather.main.temp)),
         str(round(current_weather.main.feels_like)),
         f"{current_weather.main.humidity}%" if current_weather.main.humidity else "0%",
         conditions,
-        str(round(current_weather.wind.speed))
-        if current_weather.wind and current_weather.wind.speed
-        else "0",
-        str(round(current_weather.wind.gust))
-        if current_weather.wind and current_weather.wind.gust
-        else "0",
+        wind,
+        gusts,
         rain_one_hour,
         rain_three_hour,
         snow_one_hour,
@@ -227,13 +195,13 @@ def _current_weather_all(current_weather: CurrentWeather, units: str, am_pm: boo
 
 
 def _current_weather_temp(current_weather: CurrentWeather, units: str) -> Table:
-    temp_unit = _temp_units(units)
+    _, _, _, temp_units = _get_units(units)
 
     table = Table(
         title=f"Current weather for {current_weather.name}", header_style=HEADER_ROW_STYLE
     )
-    table.add_column(f"Temperature ({temp_unit}) :thermometer:")
-    table.add_column(f"Feels Like ({temp_unit}) :thermometer:")
+    table.add_column(f"Temperature ({temp_units}) :thermometer:")
+    table.add_column(f"Feels Like ({temp_units}) :thermometer:")
     table.add_row(
         str(round(current_weather.main.temp)),
         str(round(current_weather.main.feels_like)),
@@ -243,44 +211,34 @@ def _current_weather_temp(current_weather: CurrentWeather, units: str) -> Table:
 
 
 def _daily_all(weather: OneCallWeather, units: str, am_pm: bool, location: Location) -> Table:
-    temp_unit = _temp_units(units)
-    speed_unit = _speed_units(units)
+    _, pressure_units, speed_units, temp_units = _get_units(units)
     table = Table(
         title=f"Hourly weather for {location.display_name}",
         header_style=HEADER_ROW_STYLE,
         show_lines=True,
     )
     table.add_column("Date/Time :date:")
-    table.add_column(f"Low ({temp_unit}) :thermometer:")
-    table.add_column(f"High ({temp_unit}) :thermometer:")
+    table.add_column(f"Low ({temp_units}) :thermometer:")
+    table.add_column(f"High ({temp_units}) :thermometer:")
     table.add_column("Humidity")
-    table.add_column(f"Dew Point ({temp_unit})")
-    table.add_column("Pressure")
+    table.add_column(f"Dew Point ({temp_units})")
+    table.add_column(f"Pressure {pressure_units}")
     table.add_column("UVI")
     table.add_column("Clouds")
-    table.add_column(f"Wind ({speed_unit})")
-    table.add_column(f"Wind Gusts {speed_unit}")
+    table.add_column(f"Wind ({speed_units})")
+    table.add_column(f"Wind Gusts {speed_units}")
     table.add_column("Sunrise :sunrise:")
     table.add_column("Sunset :sunset:")
 
     for daily in weather.daily:
-        if not am_pm:
-            dt = datetime.strftime(
-                (daily.dt + timedelta(seconds=weather.timezone_offset)), "%Y-%m-%d"
-            )
-            sunrise = str((daily.sunrise + timedelta(seconds=weather.timezone_offset)).time())
-            sunset = str((daily.sunset + timedelta(seconds=weather.timezone_offset)).time())
-        else:
-            dt = datetime.strftime(
-                (daily.dt + timedelta(seconds=weather.timezone_offset)),
-                "%Y-%m-%d",
-            )
-            sunrise = datetime.strftime(
-                (daily.sunrise + timedelta(seconds=weather.timezone_offset)), "%I:%M %p"
-            )
-            sunset = datetime.strftime(
-                (daily.sunset + timedelta(seconds=weather.timezone_offset)), "%I:%M %p"
-            )
+        dt = _format_date_time(am_pm, daily.dt, weather.timezone_offset, "daily")
+        sunrise, sunset = _format_sunrise_sunset(
+            am_pm, daily.sunrise, daily.sunset, weather.timezone_offset
+        )
+
+        wind = _format_wind(daily.wind_speed, units)
+        gusts = _format_wind(daily.wind_gust, units)
+        pressure = _format_pressure(daily.pressure, units)
 
         table.add_row(
             dt,
@@ -288,11 +246,11 @@ def _daily_all(weather: OneCallWeather, units: str, am_pm: bool, location: Locat
             str(round(daily.temp.max)),
             f"{daily.humidity}%",
             str(round(daily.dew_point)),
-            str(daily.pressure),
+            pressure,
             str(daily.uvi),
             f"{daily.clouds}%",
-            str(round(daily.wind_speed)),
-            str(round(daily.wind_gust)),
+            wind,
+            gusts,
             sunrise,
             sunset,
         )
@@ -301,18 +259,18 @@ def _daily_all(weather: OneCallWeather, units: str, am_pm: bool, location: Locat
 
 
 def _daily_temp_only(weather: OneCallWeather, units: str, am_pm: bool, location: Location) -> Table:
-    temp_unit = _temp_units(units)
+    _, _, _, temp_units = _get_units(units)
     table = Table(
         title=f"Hourly weather for {location.display_name}",
         header_style=HEADER_ROW_STYLE,
         show_lines=True,
     )
     table.add_column("Date/Time :date:")
-    table.add_column(f"Low ({temp_unit}) :thermometer:")
-    table.add_column(f"High ({temp_unit}) :thermometer:")
+    table.add_column(f"Low ({temp_units}) :thermometer:")
+    table.add_column(f"High ({temp_units}) :thermometer:")
 
     for daily in weather.daily:
-        dt = datetime.strftime((daily.dt + timedelta(seconds=weather.timezone_offset)), "%Y-%m-%d")
+        dt = _format_date_time(am_pm, daily.dt, weather.timezone_offset, "daily")
 
         table.add_row(
             dt,
@@ -323,56 +281,100 @@ def _daily_temp_only(weather: OneCallWeather, units: str, am_pm: bool, location:
     return table
 
 
+def _format_date_time(
+    am_pm: bool, dt: datetime, timezone: int, forecast_type: str | None = None
+) -> str:
+    if forecast_type == "daily":
+        return str(datetime.strftime((dt + timedelta(seconds=timezone)), "%Y-%m-%d %A"))
+
+    if not am_pm:
+        return str(datetime.strftime((dt + timedelta(seconds=timezone)), "%Y-%m-%d %H:%M"))
+    else:
+        return str(
+            datetime.strftime(
+                (dt + timedelta(seconds=timezone)),
+                "%Y-%m-%d %I:%M %p",
+            )
+        )
+
+
+def _format_precip(precip_amount: float | None, units: str) -> str:
+    if not precip_amount:
+        return "0"
+
+    return str(_mm_to_in(precip_amount)) if units == "imperial" else str(precip_amount)
+
+
+def _format_pressure(pressure: int | None, units: str) -> str:
+    if not pressure:
+        return "0"
+
+    return str(_hpa_to_in(pressure)) if units == "imperial" else str(pressure)
+
+
+def _format_wind(speed: float | None, units: str) -> str:
+    if not speed:
+        return "0"
+
+    return str(round(_kph_to_mph(speed))) if units == "imperial" else str(round(speed))
+
+
+def _format_sunrise_sunset(
+    am_pm: bool, sunrise: datetime, sunset: datetime, timezone: int
+) -> tuple[str, str]:
+    if not am_pm:
+        sunrise_format = str((sunrise + timedelta(seconds=timezone)).time())
+        sunset_format = str((sunset + timedelta(seconds=timezone)).time())
+        return sunrise_format, sunset_format
+
+    sunrise_format = datetime.strftime((sunrise + timedelta(seconds=timezone)), "%I:%M %p")
+    sunset_format = datetime.strftime((sunset + timedelta(seconds=timezone)), "%I:%M %p")
+    return sunrise_format, sunset_format
+
+
+def _get_units(units: str) -> tuple[str, str, str, str]:
+    _validate_units(units)
+    if units == "metric":
+        precip_units = "mm"
+        pressure_units = "hPa"
+        speed_units = "kph"
+        temp_units = "C"
+        return precip_units, pressure_units, speed_units, temp_units
+
+    precip_units = "in"
+    pressure_units = "in"
+    speed_units = "mph"
+    temp_units = "F"
+    return precip_units, pressure_units, speed_units, temp_units
+
+
 def _hourly_all(weather: OneCallWeather, units: str, am_pm: bool, location: Location) -> Table:
-    temp_unit = _temp_units(units)
-    speed_unit = _speed_units(units)
-    precip_units = _precip_units(units)
+    precip_units, pressure_units, speed_units, temp_units = _get_units(units)
     table = Table(
         title=f"Hourly weather for {location.display_name}",
         header_style=HEADER_ROW_STYLE,
         show_lines=True,
     )
     table.add_column("Date/Time :date:")
-    table.add_column(f"Temperature ({temp_unit}) :thermometer:")
-    table.add_column(f"Feels Like ({temp_unit}) :thermometer:")
+    table.add_column(f"Temperature ({temp_units}) :thermometer:")
+    table.add_column(f"Feels Like ({temp_units}) :thermometer:")
     table.add_column("Humidity")
-    table.add_column(f"Dew Point ({temp_unit})")
-    table.add_column("Pressure")
+    table.add_column(f"Dew Point ({temp_units})")
+    table.add_column(f"Pressure {pressure_units}")
     table.add_column("UVI")
     table.add_column("Clouds")
-    table.add_column(f"Wind ({speed_unit})")
-    table.add_column(f"Wind Gusts {speed_unit}")
+    table.add_column(f"Wind ({speed_units})")
+    table.add_column(f"Wind Gusts {speed_units}")
     table.add_column(f"Rain ({precip_units}) :cloud_with_rain:")
     table.add_column(f"Snow ({precip_units}) :snowflake:")
 
     for hourly in weather.hourly:
-        if not am_pm:
-            dt = datetime.strftime(
-                (hourly.dt + timedelta(seconds=weather.timezone_offset)), "%Y-%m-%d %H:%M"
-            )
-        else:
-            dt = datetime.strftime(
-                (hourly.dt + timedelta(seconds=weather.timezone_offset)),
-                "%Y-%m-%d %I:%M %p",
-            )
-
-        if hourly.rain:
-            rain = (
-                str(_mm_to_in(hourly.rain.one_hour))
-                if units == "imperial"
-                else str(hourly.rain.one_hour)
-            )
-        else:
-            rain = "0"
-
-        if hourly.snow:
-            snow = (
-                str(_mm_to_in(hourly.snow.one_hour))
-                if units == "imperial"
-                else str(hourly.snow.one_hour)
-            )
-        else:
-            snow = "0"
+        dt = _format_date_time(am_pm, hourly.dt, weather.timezone_offset)
+        rain = _format_precip(hourly.rain.one_hour, units) if hourly.rain else "0"
+        snow = _format_precip(hourly.snow.one_hour, units) if hourly.snow else "0"
+        wind = _format_wind(hourly.wind_speed, units)
+        gusts = _format_wind(hourly.wind_gust, units)
+        pressure = _format_pressure(hourly.pressure, units)
 
         table.add_row(
             dt,
@@ -380,11 +382,11 @@ def _hourly_all(weather: OneCallWeather, units: str, am_pm: bool, location: Loca
             str(round(hourly.feels_like)),
             f"{hourly.humidity}%",
             str(round(hourly.dew_point)),
-            str(hourly.pressure),
+            pressure,
             str(hourly.uvi),
             f"{hourly.clouds}%",
-            str(round(hourly.wind_speed)),
-            str(round(hourly.wind_gust)),
+            wind,
+            gusts,
             rain,
             snow,
         )
@@ -395,26 +397,18 @@ def _hourly_all(weather: OneCallWeather, units: str, am_pm: bool, location: Loca
 def _hourly_temp_only(
     weather: OneCallWeather, units: str, am_pm: bool, location: Location
 ) -> Table:
-    temp_unit = _temp_units(units)
+    _, _, _, temp_units = _get_units(units)
     table = Table(
         title=f"Hourly weather for {location.display_name}",
         header_style=HEADER_ROW_STYLE,
         show_lines=True,
     )
     table.add_column("Date/Time :date:")
-    table.add_column(f"Temperature ({temp_unit}) :thermometer:")
-    table.add_column(f"Feels Like ({temp_unit}) :thermometer:")
+    table.add_column(f"Temperature ({temp_units}) :thermometer:")
+    table.add_column(f"Feels Like ({temp_units}) :thermometer:")
 
     for hourly in weather.hourly:
-        if not am_pm:
-            dt = datetime.strftime(
-                (hourly.dt + timedelta(seconds=weather.timezone_offset)), "%Y-%m-%d %H:%M"
-            )
-        else:
-            dt = datetime.strftime(
-                (hourly.dt + timedelta(seconds=weather.timezone_offset)),
-                "%Y-%m-%d %I:%M %p",
-            )
+        dt = _format_date_time(am_pm, hourly.dt, weather.timezone_offset)
 
         table.add_row(
             dt,
@@ -425,25 +419,18 @@ def _hourly_temp_only(
     return table
 
 
+def _hpa_to_in(value: float) -> float:
+    return round(value / 33.863886666667, 2)
+
+
+def _kph_to_mph(value: float) -> float:
+    return value / 1.609
+
+
 def _mm_to_in(value: float) -> float:
     return round(value / 25.4, 2)
 
 
-def _precip_units(units: str) -> str:
-    _validate_units(units)
-    return "mm" if units == "metric" else "in"
-
-
-def _speed_units(units: str) -> str:
-    _validate_units(units)
-    return "kph" if units == "metric" else "mph"
-
-
-def _temp_units(units: str) -> str:
-    _validate_units(units)
-    return "C" if units == "metric" else "F"
-
-
 def _validate_units(units: str) -> None:
     if units not in ["metric", "imperial"]:
         raise ValueError("Units must either be metric or imperial")
